//
//  ProgInfoCtr.m  - handles the display of the "Memory Usage by this program" table
//  VMTester
//
//  Created by Cameron Hayne on 30/11/04.
//  Copyright 2006 Hayne of Tintagel.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#import "ProgInfoCtr.h"

#define BYTES_PER_MB (1024.0 * 1024.0)

// private ProgInfoCtr methods
@interface ProgInfoCtr (Private)
- (NSString *)strMB:(long)numPages;
@end

@implementation ProgInfoCtr

- (id)initWithPageSizeMB:(float)pageSizeMB
{
    myPageSizeMB = pageSizeMB;
    return self;
}

- (void)dealloc
{
    [super dealloc];
}

// utility method
- (NSString *)strMB:(long) numBytes
{
    return [NSString stringWithFormat: @"%.2f", numBytes / BYTES_PER_MB];
}

// used for exporting the data
- (NSString *)commaSeparatedLegend
{
    NSString *str = [NSString stringWithFormat: @"%@,%@",
                    @"RAM (MB)",
                    @"VM (MB)"
                    ];
    return str;
}

// used for exporting the data
- (NSString *)progInfoCommaSeparated:(ProgInfo *)progInfo
{
    task_basic_info_data_t *curr = &progInfo->myBasicInfo;
    NSString *str = [NSString stringWithFormat: @"%@,%@",
                    [self strMB: curr->resident_size],
                    [self strMB: curr->virtual_size]
                    ];
    return str;
}

#pragma mark Table methods
- (void)setCurrentInfo:(ProgInfo *)curr PrevInfo:(ProgInfo *)prev
{
    myCurrProgInfo = curr;
    myPrevProgInfo = prev;
}

// number of rows in the "Memory Usage by this program" table
- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
    return 2;
}

// values in the "Memory Usage by this program" table
- (id)tableView:(NSTableView *)tableView
      objectValueForTableColumn:(NSTableColumn *)tableColumn
            row:(int)row
{
    NSString * colId = [tableColumn identifier];
    if ([colId compare: @"stat"] == NSOrderedSame)
    {
        switch (row)
        {
            case 0: return @"RAM (MB)";
            case 1: return @"VM (MB)";
        }
    }
    else if ([colId compare: @"value"] == NSOrderedSame)
    {
        if (myCurrProgInfo == nil)
        {
            return @"0";
        }
        
        task_basic_info_data_t *curr = &myCurrProgInfo->myBasicInfo;
        switch (row)
        {
            case 0: return [self strMB: curr->resident_size];
            case 1: return [self strMB: curr->virtual_size];
        }
    }
    else // delta
    {
        if (myCurrProgInfo == nil || myPrevProgInfo == nil)
        {
            return @"0";
        }
        
        task_basic_info_data_t *curr = &myCurrProgInfo->myBasicInfo;
        task_basic_info_data_t *prev = &myPrevProgInfo->myBasicInfo;
        switch (row)
        {
            case 0: return [self strMB: curr->resident_size - prev->resident_size];
            case 1: return [self strMB: curr->virtual_size - prev->virtual_size];
        }
    }
}

@end
