/*
 *  resourceLimits.c
 *  VMTester
 *
 *  Created by Cameron Hayne on 23/02/09.
 *  Copyright 2009 Hayne of Tintagel. All rights reserved.
 *
 */

#include <stdio.h>
#include <sys/resource.h>
#include <errno.h>

static char *getResName(int resId)
{
    switch (resId)
    {
        case RLIMIT_CORE:
            return "RLIMIT_CORE";
        case RLIMIT_CPU:
            return "RLIMIT_CPU";
        case RLIMIT_DATA:
            return "RLIMIT_DATA";
        case RLIMIT_FSIZE:
            return "RLIMIT_FSIZE";
        case RLIMIT_MEMLOCK:
            return "RLIMIT_MEMLOCK";
        case RLIMIT_NOFILE:
            return "RLIMIT_NOFILE";
        case RLIMIT_NPROC:
            return "RLIMIT_NPROC";
        case RLIMIT_RSS:
            return "RLIMIT_RSS";
        case RLIMIT_STACK:
            return "RLIMIT_STACK";
        default:
            return "Unknown resource";
    }
}

static char* getValueStr(rlim_t lim, char *valueStr)
{
    if (lim == RLIM_INFINITY)
    {
        sprintf(valueStr, "%s", "unlimited");
    }
    else
    {
        sprintf(valueStr, "%llu", (unsigned long long)lim);
    }
}

void printResourceLimit(int resId)
{
    struct rlimit limit;
    char *resName = getResName(resId);
    if (getrlimit(resId , &limit) != 0)
    {
        fprintf(stderr, "getrlimit(%s) failed, errno: %d\n",
                resName, errno);
        return;
    }

    char curValStr[100];
    char maxValStr[100];
    getValueStr(limit.rlim_cur, curValStr);
    getValueStr(limit.rlim_max, maxValStr);
    printf("%16s curr: %10s\tmax: %10s\n", resName, curValStr, maxValStr);
}

void printResourceLimits()
{
    printf("Resource Limits from getrlimit:\n");
    printResourceLimit(RLIMIT_CORE);
    printResourceLimit(RLIMIT_CPU);
    printResourceLimit(RLIMIT_DATA);
    printResourceLimit(RLIMIT_FSIZE);
    printResourceLimit(RLIMIT_MEMLOCK);
    printResourceLimit(RLIMIT_NOFILE);
    printResourceLimit(RLIMIT_NPROC);
    printResourceLimit(RLIMIT_RSS);
    printResourceLimit(RLIMIT_STACK);
}

#ifdef UNIT_TEST
int main()
{
    printResourceLimits();
    return 0;
}
#endif


